#!/usr/bin/env python3
"""
Script de prueba para demostrar el uso de notificaciones
cuando se completan tareas en el sistema LIMS
"""

import time
import subprocess
import sys

def notify_completion():
    """Envía una notificación de sonido cuando se completa una tarea"""
    try:
        # Ejecutar el comando de PowerShell para el beep
        subprocess.run(['powershell.exe', '-c', '[System.Media.SystemSounds]::Beep.Play()'], check=True)
        print("[OK] Notificación enviada exitosamente")
    except subprocess.CalledProcessError:
        print("[ERROR] Error al enviar notificación")
    except FileNotFoundError:
        print("[ERROR] PowerShell no encontrado en el sistema")

def simulate_task():
    """Simula una tarea que toma tiempo"""
    print("Iniciando tarea de prueba...")
    
    # Simular trabajo
    for i in range(3):
        print(f"  Procesando... {i+1}/3")
        time.sleep(1)
    
    print("[OK] Tarea completada!")
    return True

def main():
    print("=== Prueba de Sistema de Notificaciones LIMS ===\n")
    
    # Ejecutar tarea
    if simulate_task():
        print("\nEnviando notificación de finalización...")
        notify_completion()
    
    print("\n=== Fin de la prueba ===")

if __name__ == "__main__":
    main()